@@ -12,7 +12,7 @@
 ##   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ##   GNU General Public License for more details.
 
-# $Id: protocol.py,v 1.53 2006/01/18 21:38:00 normanr Exp $
+# $Id: protocol.py,v 1.58 2007/05/13 17:55:46 normanr Exp $
 
 """
 Protocol module contains tools that is needed for processing of 
@@ -21,74 +21,115 @@ xmpp-related data structures.
 
 from simplexml import Node,ustr
 import time
-NS_ACTIVITY     ='http://jabber.org/protocol/activity'                  # JEP-0108
-NS_ADDRESS      ='http://jabber.org/protocol/address'                   # JEP-0033
-NS_AGENTS       ='jabber:iq:agents'
-NS_AMP          ='http://jabber.org/protocol/amp'
-NS_AMP_ERRORS   =NS_AMP+'#errors'
-NS_AUTH         ='jabber:iq:auth'
-NS_BIND         ='urn:ietf:params:xml:ns:xmpp-bind'
-NS_BROWSE       ='jabber:iq:browse'
-NS_BYTESTREAM   ='http://jabber.org/protocol/bytestreams'               # JEP-0065
-NS_CAPS         ='http://jabber.org/protocol/caps'                      # JEP-0115
-NS_CHATSTATES   ='http://jabber.org/protocol/chatstates'                # JEP-0085
-NS_CLIENT       ='jabber:client'
-NS_COMMANDS     ='http://jabber.org/protocol/commands'
-NS_COMPONENT_ACCEPT='jabber:component:accept'
-NS_COMPONENT_1  ='http://jabberd.jabberstudio.org/ns/component/1.0'
-NS_COMPRESS     ='http://jabber.org/protocol/compress'                  # JEP-0138
-NS_DATA         ='jabber:x:data'                                        # JEP-0004
-NS_DELAY        ='jabber:x:delay'
-NS_DIALBACK     ='jabber:server:dialback'
-NS_DISCO        ='http://jabber.org/protocol/disco'
-NS_DISCO_INFO   =NS_DISCO+'#info'
-NS_DISCO_ITEMS  =NS_DISCO+'#items'
-NS_ENCRYPTED    ='jabber:x:encrypted'                                   # JEP-0027
-NS_EVENT        ='jabber:x:event'                                       # JEP-0022
-NS_FEATURE      ='http://jabber.org/protocol/feature-neg'  
-NS_FILE         ='http://jabber.org/protocol/si/profile/file-transfer'  # JEP-0096
-NS_GEOLOC       ='http://jabber.org/protocol/geoloc'                    # JEP-0080
-NS_GROUPCHAT    ='gc-1.0'
-NS_HTTP_BIND    ='http://jabber.org/protocol/httpbind'                  # JEP-0124
-NS_IBB          ='http://jabber.org/protocol/ibb'
-NS_INVISIBLE    ='presence-invisible'                                   # Jabberd2
-NS_IQ           ='iq'                                                   # Jabberd2
-NS_LAST         ='jabber:iq:last'
-NS_MESSAGE      ='message'                                              # Jabberd2
-NS_MOOD         ='http://jabber.org/protocol/mood'                      # JEP-0107
-NS_MUC          ='http://jabber.org/protocol/muc'
-NS_MUC_USER     =NS_MUC+'#user'
-NS_MUC_ADMIN    =NS_MUC+'#admin'
-NS_MUC_OWNER    =NS_MUC+'#owner'
-NS_OFFLINE      ='http://www.jabber.org/jeps/jep-0030.html'             # JEP-0013
-NS_PHYSLOC      ='http://jabber.org/protocol/physloc'                   # JEP-0112
-NS_PRESENCE     ='presence'                                             # Jabberd2
-NS_PRIVACY      ='jabber:iq:privacy'
-NS_PRIVATE      ='jabber:iq:private'
-NS_PUBSUB       ='http://jabber.org/protocol/pubsub'                    # JEP-0060
-NS_REGISTER     ='jabber:iq:register'
-NS_ROSTER       ='jabber:iq:roster'
-NS_ROSTERX      ='http://jabber.org/protocol/rosterx'                   # JEP-0144
-NS_RPC          ='jabber:iq:rpc'                                        # JEP-0009
-NS_SASL         ='urn:ietf:params:xml:ns:xmpp-sasl'
-NS_SEARCH       ='jabber:iq:search'
-NS_SERVER       ='jabber:server'
-NS_SESSION      ='urn:ietf:params:xml:ns:xmpp-session'
-NS_SI           ='http://jabber.org/protocol/si'                        # JEP-0096
-NS_SI_PUB       ='http://jabber.org/protocol/sipub'                     # JEP-0137
-NS_SIGNED       ='jabber:x:signed'                                      # JEP-0027
-NS_STANZAS      ='urn:ietf:params:xml:ns:xmpp-stanzas'
-NS_STREAMS      ='http://etherx.jabber.org/streams'
-NS_TIME         ='jabber:iq:time'
-NS_TLS          ='urn:ietf:params:xml:ns:xmpp-tls'
-NS_VACATION     ='http://jabber.org/protocol/vacation'
-NS_VCARD        ='vcard-temp'
-NS_VERSION      ='jabber:iq:version'
-NS_WAITINGLIST  ='http://jabber.org/protocol/waitinglist'               # JEP-0130
-NS_XHTML_IM     ='http://jabber.org/protocol/xhtml-im'                  # JEP-0071
-NS_DATA_LAYOUT  ='http://jabber.org/protocol/xdata-layout'              # JEP-0141
-NS_DATA_VALIDATE='http://jabber.org/protocol/xdata-validate'            # JEP-0122
-NS_XMPP_STREAMS ='urn:ietf:params:xml:ns:xmpp-streams'
+NS_ACTIVITY         ='http://jabber.org/protocol/activity'                  # XEP-0108
+NS_ADDRESS          ='http://jabber.org/protocol/address'                   # XEP-0033
+NS_ADMIN            ='http://jabber.org/protocol/admin'                     # XEP-0133
+NS_ADMIN_ADD_USER               =NS_ADMIN+'#add-user'                       # XEP-0133
+NS_ADMIN_DELETE_USER            =NS_ADMIN+'#delete-user'                    # XEP-0133
+NS_ADMIN_DISABLE_USER           =NS_ADMIN+'#disable-user'                   # XEP-0133
+NS_ADMIN_REENABLE_USER          =NS_ADMIN+'#reenable-user'                  # XEP-0133
+NS_ADMIN_END_USER_SESSION       =NS_ADMIN+'#end-user-session'               # XEP-0133
+NS_ADMIN_GET_USER_PASSWORD      =NS_ADMIN+'#get-user-password'              # XEP-0133
+NS_ADMIN_CHANGE_USER_PASSWORD   =NS_ADMIN+'#change-user-password'           # XEP-0133
+NS_ADMIN_GET_USER_ROSTER        =NS_ADMIN+'#get-user-roster'                # XEP-0133
+NS_ADMIN_GET_USER_LASTLOGIN     =NS_ADMIN+'#get-user-lastlogin'             # XEP-0133
+NS_ADMIN_USER_STATS             =NS_ADMIN+'#user-stats'                     # XEP-0133
+NS_ADMIN_EDIT_BLACKLIST         =NS_ADMIN+'#edit-blacklist'                 # XEP-0133
+NS_ADMIN_EDIT_WHITELIST         =NS_ADMIN+'#edit-whitelist'                 # XEP-0133
+NS_ADMIN_REGISTERED_USERS_NUM   =NS_ADMIN+'#get-registered-users-num'       # XEP-0133
+NS_ADMIN_DISABLED_USERS_NUM     =NS_ADMIN+'#get-disabled-users-num'         # XEP-0133
+NS_ADMIN_ONLINE_USERS_NUM       =NS_ADMIN+'#get-online-users-num'           # XEP-0133
+NS_ADMIN_ACTIVE_USERS_NUM       =NS_ADMIN+'#get-active-users-num'           # XEP-0133
+NS_ADMIN_IDLE_USERS_NUM         =NS_ADMIN+'#get-idle-users-num'             # XEP-0133
+NS_ADMIN_REGISTERED_USERS_LIST  =NS_ADMIN+'#get-registered-users-list'      # XEP-0133
+NS_ADMIN_DISABLED_USERS_LIST    =NS_ADMIN+'#get-disabled-users-list'        # XEP-0133
+NS_ADMIN_ONLINE_USERS_LIST      =NS_ADMIN+'#get-online-users-list'          # XEP-0133
+NS_ADMIN_ACTIVE_USERS_LIST      =NS_ADMIN+'#get-active-users-list'          # XEP-0133
+NS_ADMIN_IDLE_USERS_LIST        =NS_ADMIN+'#get-idle-users-list'            # XEP-0133
+NS_ADMIN_ANNOUNCE               =NS_ADMIN+'#announce'                       # XEP-0133
+NS_ADMIN_SET_MOTD               =NS_ADMIN+'#set-motd'                       # XEP-0133
+NS_ADMIN_EDIT_MOTD              =NS_ADMIN+'#edit-motd'                      # XEP-0133
+NS_ADMIN_DELETE_MOTD            =NS_ADMIN+'#delete-motd'                    # XEP-0133
+NS_ADMIN_SET_WELCOME            =NS_ADMIN+'#set-welcome'                    # XEP-0133
+NS_ADMIN_DELETE_WELCOME         =NS_ADMIN+'#delete-welcome'                 # XEP-0133
+NS_ADMIN_EDIT_ADMIN             =NS_ADMIN+'#edit-admin'                     # XEP-0133
+NS_ADMIN_RESTART                =NS_ADMIN+'#restart'                        # XEP-0133
+NS_ADMIN_SHUTDOWN               =NS_ADMIN+'#shutdown'                       # XEP-0133
+NS_AGENTS           ='jabber:iq:agents'                                     # XEP-0094 (historical)
+NS_AMP              ='http://jabber.org/protocol/amp'                       # XEP-0079
+NS_AMP_ERRORS                   =NS_AMP+'#errors'                           # XEP-0079
+NS_AUTH             ='jabber:iq:auth'
+NS_AVATAR           ='jabber:iq:avatar'                                     # XEP-0008 (historical)
+NS_BIND             ='urn:ietf:params:xml:ns:xmpp-bind'
+NS_BROWSE           ='jabber:iq:browse'                                     # XEP-0011 (historical)
+NS_BYTESTREAM       ='http://jabber.org/protocol/bytestreams'               # XEP-0065
+NS_CAPS             ='http://jabber.org/protocol/caps'                      # XEP-0115
+NS_CHATSTATES       ='http://jabber.org/protocol/chatstates'                # XEP-0085
+NS_CLIENT           ='jabber:client'
+NS_COMMANDS         ='http://jabber.org/protocol/commands'
+NS_COMPONENT_ACCEPT ='jabber:component:accept'
+NS_COMPONENT_1      ='http://jabberd.jabberstudio.org/ns/component/1.0'
+NS_COMPRESS         ='http://jabber.org/protocol/compress'                  # XEP-0138
+NS_DATA             ='jabber:x:data'                                        # XEP-0004
+NS_DELAY            ='jabber:x:delay'
+NS_DIALBACK         ='jabber:server:dialback'
+NS_DISCO            ='http://jabber.org/protocol/disco'                     # XEP-0030
+NS_DISCO_INFO                   =NS_DISCO+'#info'                           # XEP-0030
+NS_DISCO_ITEMS                  =NS_DISCO+'#items'                          # XEP-0030
+NS_ENCRYPTED        ='jabber:x:encrypted'                                   # XEP-0027
+NS_EVENT            ='jabber:x:event'                                       # XEP-0022
+NS_FEATURE          ='http://jabber.org/protocol/feature-neg'  
+NS_FILE             ='http://jabber.org/protocol/si/profile/file-transfer'  # XEP-0096
+NS_GATEWAY          ='jabber:iq:gateway'
+NS_GEOLOC           ='http://jabber.org/protocol/geoloc'                    # XEP-0080
+NS_GROUPCHAT        ='gc-1.0'
+NS_HTTP_BIND        ='http://jabber.org/protocol/httpbind'                  # XEP-0124
+NS_IBB              ='http://jabber.org/protocol/ibb'
+NS_INVISIBLE        ='presence-invisible'                                   # Jabberd2
+NS_IQ               ='iq'                                                   # Jabberd2
+NS_LAST             ='jabber:iq:last'
+NS_MESSAGE          ='message'                                              # Jabberd2
+NS_MOOD             ='http://jabber.org/protocol/mood'                      # XEP-0107
+NS_MUC              ='http://jabber.org/protocol/muc'                       # XEP-0045
+NS_MUC_ADMIN                    =NS_MUC+'#admin'                            # XEP-0045
+NS_MUC_OWNER                    =NS_MUC+'#owner'                            # XEP-0045
+NS_MUC_UNIQUE                   =NS_MUC+'#unique'                           # XEP-0045
+NS_MUC_USER                     =NS_MUC+'#user'                             # XEP-0045
+NS_MUC_REGISTER                 =NS_MUC+'#register'                         # XEP-0045
+NS_MUC_REQUEST                  =NS_MUC+'#request'                          # XEP-0045
+NS_MUC_ROOMCONFIG               =NS_MUC+'#roomconfig'                       # XEP-0045
+NS_MUC_ROOMINFO                 =NS_MUC+'#roominfo'                         # XEP-0045
+NS_MUC_ROOMS                    =NS_MUC+'#rooms'                            # XEP-0045
+NS_MUC_TRAFIC                   =NS_MUC+'#traffic'                          # XEP-0045
+NS_OFFLINE          ='http://jabber.org/protocol/offline'                   # XEP-0013
+NS_PHYSLOC          ='http://jabber.org/protocol/physloc'                   # XEP-0112
+NS_PRESENCE         ='presence'                                             # Jabberd2
+NS_PRIVACY          ='jabber:iq:privacy'
+NS_PRIVATE          ='jabber:iq:private'
+NS_PUBSUB           ='http://jabber.org/protocol/pubsub'                    # XEP-0060
+NS_REGISTER         ='jabber:iq:register'
+NS_ROSTER           ='jabber:iq:roster'
+NS_ROSTERX          ='http://jabber.org/protocol/rosterx'                   # XEP-0144
+NS_RPC              ='jabber:iq:rpc'                                        # XEP-0009
+NS_SASL             ='urn:ietf:params:xml:ns:xmpp-sasl'
+NS_SEARCH           ='jabber:iq:search'
+NS_SERVER           ='jabber:server'
+NS_SESSION          ='urn:ietf:params:xml:ns:xmpp-session'
+NS_SI               ='http://jabber.org/protocol/si'                        # XEP-0096
+NS_SI_PUB           ='http://jabber.org/protocol/sipub'                     # XEP-0137
+NS_SIGNED           ='jabber:x:signed'                                      # XEP-0027
+NS_STANZAS          ='urn:ietf:params:xml:ns:xmpp-stanzas'
+NS_STREAMS          ='http://etherx.jabber.org/streams'
+NS_TIME             ='jabber:iq:time'
+NS_TLS              ='urn:ietf:params:xml:ns:xmpp-tls'
+NS_VACATION         ='http://jabber.org/protocol/vacation'
+NS_VCARD            ='vcard-temp'
+NS_VERSION          ='jabber:iq:version'
+NS_WAITINGLIST      ='http://jabber.org/protocol/waitinglist'               # XEP-0130
+NS_XHTML_IM         ='http://jabber.org/protocol/xhtml-im'                  # XEP-0071
+NS_DATA_LAYOUT      ='http://jabber.org/protocol/xdata-layout'              # XEP-0141
+NS_DATA_VALIDATE    ='http://jabber.org/protocol/xdata-validate'            # XEP-0122
+NS_XMPP_STREAMS     ='urn:ietf:params:xml:ns:xmpp-streams'
 
 xmpp_stream_error_conditions="""
 bad-format --  --  -- The entity has sent XML that cannot be processed.
@@ -542,9 +583,9 @@ class Error(Protocol):
 
 class DataField(Node):
     """ This class is used in the DataForm class to describe the single data item.
-        If you are working with jabber:x:data (JEP-0004, JEP-0068, JEP-0122) 
+        If you are working with jabber:x:data (XEP-0004, XEP-0068, XEP-0122) 
         then you will need to work with instances of this class. """
-    def __init__(self,name=None,value=None,typ=None,required=0,desc=None,options=[],node=None):
+    def __init__(self,name=None,value=None,typ=None,required=0,label=None,desc=None,options=[],node=None):
         """ Create new data field of specified name,value and type.
             Also 'required','desc' and 'options' fields can be set.
             Alternatively other XML object can be passed in as the 'node' parameted to replicate it as a new datafiled.
@@ -556,6 +597,7 @@ class DataField(Node):
         if typ: self.setType(typ)
         elif not typ and not node: self.setType('text-single')
         if required: self.setRequired(required)
+        if label: self.setLabel(label)
         if desc: self.setDesc(desc)
         if options: self.setOptions(options)
     def setRequired(self,req=1):
@@ -567,6 +609,12 @@ class DataField(Node):
     def isRequired(self):
         """ Returns in this field a required one. """
         return self.getTag('required')
+    def setLabel(self,label):
+        """ Set the label of this field. """
+        self.setAttr('label',label)
+    def getLabel(self):
+        """ Return the label of this field. """
+        return self.getAttr('label')
     def setDesc(self,desc):
         """ Set the description of this field. """
         self.setTagData('desc',desc)
@@ -619,7 +667,7 @@ class DataField(Node):
 
 class DataForm(Node):
     """ DataForm class. Used for manipulating dataforms in XMPP.
-        Relevant JEPs: 0004, 0068, 0122.
+        Relevant XEPs: 0004, 0068, 0122.
         Can be used in disco, pub-sub and many other applications."""
     def __init__(self, typ=None, data=[], title=None, node=None):
         """
